@@ -108,6 +108,8 @@ def apply_design_rules(anm):
     build_vrf(anm) # need to do before to add loopbacks before ip allocations
     build_ip(anm) # ip infrastructure topology
 
+#TODO: set defaults at the start, rather than inline, ie set g_in.data.address_family then use later
+
     address_family = g_in.data.address_family or "v4" # default is v4
 #TODO: can remove the infrastructure now create g_ip seperately
     if address_family in ("v4", "dual_stack"):
@@ -872,6 +874,7 @@ def build_phy(anm):
         g_phy.data.mgmt_address_end = g_in.data.mgmt_address_end 
         g_phy.data.mgmt_prefixlen = g_in.data.mgmt_prefixlen
         ank_utils.copy_attr_from(g_in, g_phy, "use_cdp")
+        ank_utils.copy_attr_from(g_in, g_phy, "use_onepk")
 
     g_phy.add_edges_from(g_in.edges(type="physical"))
     # TODO: make this automatic if adding to the physical graph?
