@@ -78,7 +78,6 @@ def manage_network(input_graph_string, timestamp, build_options, reload_build=Fa
         nidb.restore_latest()
         update_http(anm, nidb)
 
-
     if build_options['diff']:
         import autonetkit.diff
         nidb_diff = autonetkit.diff.nidb_diff()
@@ -136,6 +135,7 @@ def parse_options():
                         default=False, help="Measure")
     parser.add_argument('--webserver', action="store_true", default=False, help="Webserver")
     parser.add_argument('--grid', type=int, help="Grid Size (n * n)")
+    parser.add_argument('--target', choices=['netkit', 'cisco'], default = None)
     arguments = parser.parse_args()
     return arguments
 
@@ -147,6 +147,17 @@ def main():
 
 # TODO: only allow monitor mode with options.file not options.stdin
 
+    if options.target == "cisco":
+        # output target is Cisco
+        log.info("Setting output target as Cisco")
+        settings['Graphml']['Node Defaults']['platform'] = "cisco"
+        settings['Graphml']['Node Defaults']['host'] = "internal"
+        settings['Graphml']['Node Defaults']['syntax'] = "ios2"
+        settings['Compiler']['Cisco']['to memory'] = 1
+        settings['General']['deploy'] = 1
+        settings['Deploy Hosts']['internal'] = {'cisco': 
+                {'deploy': 1}}
+
     if options.debug or settings['General']['debug']:
         # TODO: fix this
         import logging
@@ -307,10 +318,16 @@ def deploy_network(anm, nidb, input_graph_string = None):
                 except ImportError:
                     pass  # development module, may not be available
                 if platform == "cisco":
-                    if input_graph_string: # input xml file
-                        cisco_deploy.package(nidb, config_path, input_graph_string)
-                    else:
+                    create_new_xml = False
+                    if not input_graph_string:
+                        create_new_xml = True # no input, eg if came from grid
+                    elif anm['input'].data['file_type'] == "graphml":
+                        create_new_xml = True # input from graphml, create XML
+
+                    if create_new_xml:
                         cisco_deploy.create_xml(anm, nidb, input_graph_string)
+                    else:
+                        cisco_deploy.package(nidb, config_path, input_graph_string)
                 continue
 
             username = platform_data['username']
@@ -368,7 +385,7 @@ def measure_network(anm, nidb):
     import autonetkit.measure as measure
 
     log.info("Measuring network")
-    if 0:
+    if 1:
         remote_hosts = [node.tap.ip for node in nidb.nodes("is_router")]
         dest_node = random.choice([n for n in nidb.nodes("is_l3device")])
         log.info("Tracing to randomly selected node: %s" % dest_node)
@@ -376,7 +393,7 @@ def measure_network(anm, nidb):
         command = "traceroute -n -a -U -w 0.5 %s" % dest_ip
         measure.send(nidb, command, remote_hosts, threads = 10)
     # abort after 10 fails, proceed on any success, 0.1 second timeout (quite aggressive)
-    if 1:
+    if 0:
         collect_sh_ip_route(anm, nidb)
 
 
