@@ -8,6 +8,9 @@ var g_groupings = chart.append("svg:g")
 var g_links = chart.append("svg:g")
 .attr("id", "g_links");
 
+var g_link_highlights = chart.append("svg:g")
+.attr("id", "g_link_highlights");
+
 var g_nodes = chart.append("svg:g")
 .attr("id", "g_nodes");
 
@@ -122,7 +125,7 @@ ws.onmessage = function (evt) {
         apply_highlight(data['highlight']);
     }
     else {
-        //console.log("Received unknown data", data);
+        console.log("Received unknown data", data);
         //TODO: work out why reaching here if passing the "graph in data" check above
     }
 }
@@ -130,9 +133,9 @@ ws.onmessage = function (evt) {
 highlight_nodes = [];
 highlight_edges = [];
 
+abc = [];
 var apply_highlight = function(data){
 
-
     highlight_nodes = _.map(data['nodes'], function(n) {
         return nodes_by_id[n];
     })
@@ -1356,7 +1359,7 @@ function redraw() {
     });
 
 
-    var highlight_line = chart.selectAll(".highlight_line")
+    var highlight_line = g_link_highlights.selectAll(".highlight_line")
         .data(highlight_edges)
 
         //line.enter().append("line")
@@ -1370,9 +1373,9 @@ function redraw() {
         .style("stroke-width", function() {
             //TODO: use this stroke-width function on mouseout too
             if (jsondata.directed) {
-                return 3;
+                return 5;
             } 
-            return 3;
+            return 5;
         })
     //.attr("marker-end", marker_end)
     .style("stroke", "red")
@@ -1579,9 +1582,7 @@ function redraw() {
         image
         .attr("width", icon_width)
         .attr("height", icon_height)
-        .attr("xlink:href", function(d) {return "#icon_" + node_icon(d)})
         .transition()
-        .attr("xlink:href", function(d) {return "#icon_" + node_icon(d)})
         .style("opacity", icon_opacity)
         .attr("x", function(d) { return d.x + x_offset; })
         .attr("y", function(d) { return d.y + y_offset; })
@@ -1665,16 +1666,16 @@ function redraw_paths() {
 
     var path_color = function(d) { 
         if ("verified" in d && d['verified'] == true) {
-            return "rgb(0,128,64)";
+            return "red";
         }
-        return "rgb(25,52,65)";
+        return "red";
     }
 
     trace_path.enter().append("svg:path")
         .attr("d", function(d) { return svg_line(d['path'])})
         .attr("class", "trace_path")
         .style("stroke-width", 5)
-        .style("stroke", "rgb(207,120,33)")
+        .style("stroke", "red")
         .style("fill", "none")
         .attr("stroke-dasharray", function(d) {
             return path_total_length(d3.select(this)) + " " + path_total_length(d3.select(this))})
@@ -1695,7 +1696,7 @@ function redraw_paths() {
 
         trace_path
           .on("mouseover", function(d){
-            d3.select(this).style("stroke", "rgb(242,130,6)");
+            d3.select(this).style("stroke", "red");
             d3.select(this).style("stroke-width", "4");
             //path_info(d);
             console.log(d.verified);
